==> jAddo___2022-12-16_03-18-14.zip: src/footer.php <==
<footer class="footer">
        <div class="footer-map pt-lg-5 bg-black-pearl">
            <div class="container-lg pt-lg-5 mt-lg-5">
                <div class="row justify-content-end pt-lg-2">
                    <div class="col-12 col-lg-10">
                        <div class="footer-map-img bg-img-cover bg-img-pos-bottom position-relative d-flex" style="background-image: url(assets/images/Basemap-image.png);">
                            <div class="footer-map-alt position-absolute d-none d-lg-block">
                                <a href="https://www.google.com/maps/dir/?api=1&destination=15%2042+Union+St,+Smiths+Falls,+ON+K7A+5C4,+Kanada/@42.2333765,-64.4506748,3z/data=!3m1!4b1!4m9!4m8!1m1!4e1!1m5!1m1!1s0x4cd20f1ab62d332f:0x727f799eab9d5b3a!2m2!1d-76.0235129!2d44.9123302" target="_blank" class="">
                                    <i class="bi bi-geo-alt-fill text-primary text-xs"></i>
                                </a>
                            </div>
                            <div class="footer-map-text px-5 pb-5 pb-md-3 pt-5 p-lg-5 w-100 d-none d-lg-flex flex-column justify-content-end">
                                <p class="text-xxs text-700 lh-1 text-primary text-uppercase mb-3 mb-lg-4 pb-lg-2 ">off-road motorbike helmets</p>
                                <h2 class="headline-2 text-800 lh-1 text-uppercase w-100 mb-0">contacts <span class="d-block"> and location</span></h2>
                            </div>
                        </div>
                    </div>
                    <div class="col-1 d-none d-lg-block">
                        <div class="d-flex flex-wrap h-100 align-content-center">
                            <a href="https://www.facebook.com" target="_blank" class="social-media-icon w-100 text-center d-inline-flex justify-content-center py-4">
                                <img src="assets/images/Icon/social_icon/facebook.svg" height="32" alt="">
                            </a>
                            <a href="https://www.twitter.com" target="_blank" class="social-media-icon w-100 text-center d-inline-flex justify-content-center py-4">
                                <img src="assets/images/Icon/social_icon/twitter.svg" height="32" alt="">
                            </a>
                            <a href="https://www.instagram.com" target="_blank" class="social-media-icon w-100 text-center d-inline-flex justify-content-center py-4">
                                <img src="assets/images/Icon/social_icon/instagram.svg" height="32" alt="">
                            </a>
                        </div>
                    </div>
                </div>
            </div>      
        </div>
        <div class="footer-contact" style="background: linear-gradient(90deg, #171718 0%, #242626 100%), linear-gradient(360deg, #000000 83.64%, rgba(0, 0, 0, 0) 98.39%);">
            <div class="container pb-5 pb-lg-2">
                <div class="row pb-5 py-lg-5 mb-5 mb-lg-3 justify-content-center justify-content-lg-start text-center text-lg-start">
                    <div class="footer-text pb-5 pb-md-3 mb-4 mb-lg-0 d-block d-lg-none text-start">
                        <p class="text-xxs text-700 lh-1 text-primary text-uppercase mb-3 mb-lg-4 pb-lg-2">off-road motorbike helmets</p>
                        <h2 class="headline-2 text-800 lh-1 text-uppercase w-100 mb-4 mb-lg-0">contacts <span class="d-block"> and location</span></h2>
                    </div>
                    <div class="col-10 col-lg-3 col-xl-2 mb-5 mb-lg-0 order-2 order-lg-1">
                        <h5 class="headline-5 text-700 lh-1 mb-3">Address</h5>
                        <p class="text-xxs lh-1 mb-0">42 Union St, Smiths Falls <br> ON K7A 5C4, Kanada</p>
                    </div>
                    <div class="col-1 d-none d-xl-block d-xxl-none order-1"></div>
                    <div class="col-10 col-lg-3 col-xl-2 order-2">
                        <h5 class="headline-5 text-700 lh-1 mb-3">Open</h5>
                        <p class="text-xxs lh-1 text-uppercase mb-0">10:00 AM - 6:00 PM <br> MON - FRI</p>
                    </div>
                    <div class="col-2 col-xxl-3 d-none d-xl-block order-2"></div>
                    <div class="col-10 col-lg-6 col-xl-5 mb-5 mb-lg-0 d-block d-lg-flex justify-content-between align-items-center order-1 order-lg-3">
                        <h5 class="headline-5 text-700 lh-1 mb-3 d-block d-lg-none">Contact</h5>
                        <p class="text-xxs lh-1 mb-0">
                            <a href="tel:+16135663448" target="_blank" class="text-decoration-none text-white">+1 613-566-3448</a>
                        </p>
                        <p class="text-xxs lh-1 mb-0">
                            <a href="mailto:email@emialaddress.com" target="_blank" class="text-decoration-none text-white">email@emialaddress.com</a>
                        </p>
                        <p class="text-xxs lh-1 mb-0">
                            <a href="cookies.html" target="_blank" class="text-decoration-none text-white d-none d-lg-flex">Privacy Policy</a>
                        </p>                        
                    </div>
                    <div class="col-12 d-lg-none d-block order-3 pt-5 mt-5 mt-md-4 mb-3 mb-md-0">
                        <div class="d-flex justify-content-evenly">
                            <a href="https://www.facebook.com" target="_blank" class="social-media-icon text-center d-inline-flex justify-content-center">
                                <img src="assets/images/Icon/social_icon/facebook.svg" height="56" alt="">
                            </a>
                            <a href="https://www.twitter.com" target="_blank" class="social-media-icon text-center d-inline-flex justify-content-center">
                                <img src="assets/images/Icon/social_icon/twitter.svg" height="56" alt="">
                            </a>
                            <a href="https://www.instagram.com" target="_blank" class="social-media-icon text-center d-inline-flex justify-content-center">
                                <img src="assets/images/Icon/social_icon/instagram.svg" height="56" alt="">
                            </a>
                        </div>
                    </div>
                </div>
                <hr class="opacity-100 my-0" style="border: 0.5px solid rgba(140, 140, 140, 0.1);">
                <div class="row justify-content-between py-4 mt-2 mb-4 mb-lg-0">
                    <div class="col-12 col-lg-4 col-xxl-3 d-flex align-items-center justify-content-between mb-5 mb-lg-0">
                        <a href="#" class="pay-logos d-flex">
                            <img src="assets/images/Pay-Logos/Mastercard-logo-white.svg" class="w-75 pay-logos-img" height="20" alt="">
                        </a>
                        <a href="#" class="pay-logos d-flex">
                            <img src="assets/images/Pay-Logos/Visa_Inc._logo-white.svg" class="w-75 pay-logos-img" height="17" alt="">
                        </a>
                        <a href="#" class="pay-logos d-flex">
                            <img src="assets/images/Pay-Logos/PayPal-white.svg" class="w-75 pay-logos-img" height="21" alt="">
                        </a>
                        <a href="#" class="pay-logos d-flex">
                            <img src="assets/images/Pay-Logos/Klarna_Logo-white.svg" class="w-75 pay-logos-img" height="17" alt="">
                        </a>
                    </div>
                    <div class="col-12 col-lg-6 text-center text-lg-end mt-3 mt-md-2 mt-lg-0 mb-5 mb-lg-0 pb-5 pb-lg-0">
                        <p class="text-xxs lh-1 mb-0">&copy; 2022 ORV HeadQuarters All Rights Reserved</p>
                    </div>
                </div>
            </div>          
        </div>
    </footer>

==> jAddo___2022-12-16_03-19-16.zip: src/footer.php <==
<footer class="footer position-relative">
        <div class="footer-map pt-lg-5 bg-black-pearl">
            <div class="container-lg pt-lg-5 mt-lg-5">
                <div class="row justify-content-end pt-lg-2">
                    <div class="col-12 col-lg-10">
                        <div class="footer-map-img bg-img-cover bg-img-pos-bottom position-relative d-flex" style="background-image: url(assets/images/Basemap-image.png);">
                            <div class="footer-map-alt position-absolute d-none d-lg-block">
                                <a href="https://www.google.com/maps/dir/?api=1&destination=15%2042+Union+St,+Smiths+Falls,+ON+K7A+5C4,+Kanada/@42.2333765,-64.4506748,3z/data=!3m1!4b1!4m9!4m8!1m1!4e1!1m5!1m1!1s0x4cd20f1ab62d332f:0x727f799eab9d5b3a!2m2!1d-76.0235129!2d44.9123302" target="_blank" class=" text-decoration-none">
                                    <i class="icon-location1 text-primary text-xs"></i>
                                </a>
                            </div>
                            <div class="footer-map-text px-5 pb-5 pb-md-3 pt-5 p-lg-5 w-100 d-none d-lg-flex flex-column justify-content-end">
                                <p class="text-xxs text-700 lh-1 text-primary text-uppercase mb-3 mb-lg-4 pb-lg-2 ">off-road motorbike helmets</p>
                                <h2 class="headline-2 text-800 lh-1 text-uppercase w-100 mb-0">contacts <span class="d-block"> and location</span></h2>
                            </div>
                        </div>
                    </div>
                    <div class="col-1 d-none d-lg-block">
                        <div class="d-flex flex-wrap h-100 align-content-center">
                            <a href="https://www.facebook.com" target="_blank" class="social-media-icon w-100 text-center d-inline-flex justify-content-center py-4">
                                <img src="assets/images/Icon/social_icon/facebook.svg" height="32" alt="">
                            </a>
                            <a href="https://www.twitter.com" target="_blank" class="social-media-icon w-100 text-center d-inline-flex justify-content-center py-4">
                                <img src="assets/images/Icon/social_icon/twitter.svg" height="32" alt="">
                            </a>
                            <a href="https://www.instagram.com" target="_blank" class="social-media-icon w-100 text-center d-inline-flex justify-content-center py-4">
                                <img src="assets/images/Icon/social_icon/instagram.svg" height="32" alt="">
                            </a>
                        </div>
                    </div>
                </div>
            </div>      
        </div>
        <div class="footer-contact pb-5 pb-lg-2 pt-lg-3 position-relative" style="background: linear-gradient(90deg, #171718 0%, #242626 100%), linear-gradient(360deg, #000000 83.64%, rgba(0, 0, 0, 0) 98.39%);">
            <div class="container">
                <div class="row pb-5 py-lg-5 mb-5 mb-lg-3 justify-content-center justify-content-lg-start text-center text-lg-start">
                    <div class="footer-text pb-5 pb-md-3 mb-4 mb-lg-0 d-block d-lg-none text-start">
                        <p class="text-xxs text-700 lh-1 text-primary text-uppercase mb-3 mb-lg-4 pb-lg-2">off-road motorbike helmets</p>
                        <h2 class="headline-2 text-800 lh-1 text-uppercase w-100 mb-4 mb-lg-0">contacts <span class="d-block"> and location</span></h2>
                    </div>
                    <div class="col-10 col-lg-3 col-xxl-2 mb-5 mb-lg-0 order-2 order-lg-1">
                        <h5 class="headline-5 text-700 lh-1 mb-3">Address</h5>
                        <p class="text-xxs lh-1 mb-0">42 Union St, Smiths Falls <br> ON K7A 5C4, Kanada</p>
                    </div>
                    <div class="col-10 col-lg-3 col-xl-2 order-2">
                        <h5 class="headline-5 text-700 lh-1 mb-3">Open</h5>
                        <p class="text-xxs lh-1 text-uppercase mb-0">10:00 AM - 6:00 PM <br> MON - FRI</p>
                    </div>
                    <div class="col-2 col-xxl-3 d-none d-xl-block order-2"></div>
                    <div class="col-10 col-lg-6 col-xl-5 mb-5 mb-lg-0 d-block d-lg-flex justify-content-between align-items-center order-1 order-lg-3">
                        <h5 class="headline-5 text-700 lh-1 mb-3 d-block d-lg-none">Contact</h5>
                        <p class="text-xxs lh-1 mb-0">
                            <a href="tel:+16135663448" target="_blank" class="text-decoration-none text-white">+1 613-566-3448</a>
                        </p>
                        <p class="text-xxs lh-1 mb-0">
                            <a href="mailto:email@emialaddress.com" target="_blank" class="text-decoration-none text-white">email@emialaddress.com</a>
                        </p>
                        <p class="text-xxs lh-1 mb-0">
                            <a href="cookies.html" target="_blank" class="text-decoration-none text-white d-none d-lg-flex">Privacy Policy</a>
                        </p>                        
                    </div>
                    <div class="col-12 d-lg-none d-block order-3 pt-5 mt-5 mt-md-4 mb-3 mb-md-0">
                        <div class="d-flex justify-content-evenly">
                            <a href="https://www.facebook.com" target="_blank" class="social-media-icon text-center d-inline-flex justify-content-center">
                                <img src="assets/images/Icon/social_icon/facebook.svg" height="56" alt="">
                            </a>
                            <a href="https://www.twitter.com" target="_blank" class="social-media-icon text-center d-inline-flex justify-content-center">
                                <img src="assets/images/Icon/social_icon/twitter.svg" height="56" alt="">
                            </a>
                            <a href="https://www.instagram.com" target="_blank" class="social-media-icon text-center d-inline-flex justify-content-center">
                                <img src="assets/images/Icon/social_icon/instagram.svg" height="56" alt="">
                            </a>
                        </div>
                    </div>
                </div>
                <hr class="opacity-100 my-0" style="border: 0.5px solid rgba(140, 140, 140, 0.1);">
                <div class="row justify-content-between py-4 mt-2 mb-4 mb-lg-0">
                    <div class="col-12 col-lg-4 col-xxl-3 d-flex align-items-center justify-content-between mb-5 mb-lg-0">
                        <a href="#" class="pay-logos d-flex">
                            <img src="assets/images/Pay-Logos/Mastercard-logo-white.svg" class="w-75 pay-logos-img" height="20" alt="">
                        </a>
                        <a href="#" class="pay-logos d-flex">
                            <img src="assets/images/Pay-Logos/Visa_Inc._logo-white.svg" class="w-75 pay-logos-img" height="17" alt="">
                        </a>
                        <a href="#" class="pay-logos d-flex">
                            <img src="assets/images/Pay-Logos/PayPal-white.svg" class="w-75 pay-logos-img" height="21" alt="">
                        </a>
                        <a href="#" class="pay-logos d-flex">
                            <img src="assets/images/Pay-Logos/Klarna_Logo-white.svg" class="w-75 pay-logos-img" height="17" alt="">
                        </a>
                    </div>
                    <div class="col-12 col-lg-6 text-center text-lg-end mt-3 mt-md-2 mt-lg-0 mb-5 mb-lg-0 pb-5 pb-lg-0">
                        <p class="text-xxs lh-1 mb-0">&copy; 2022 ORV HeadQuarters All Rights Reserved</p>
                    </div>
                </div>
            </div>          
        </div>
    </footer>
